developerscripttools.BuildApiScript
===================================

.. abjad-lineage:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript

.. autoclass:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.BuildApiScript.BuildApiScript.BuildApiScript.__repr__
   :noindex:
